==> verttice_ui-0.0.52.tar.gz: lib/src/widgets/files/video_viewer_storage.dart <==
import 'package:chewie/chewie.dart';
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_ui/src/base_config.dart';
import 'package:verttice_ui/src/config/config.dart';
import "package:verttice_ui/src/const/box_sizes.dart";
import "package:verttice_ui/src/const/icons.dart";
import "package:flutter/material.dart";
import 'package:verttice_ui/src/widgets/download_button.dart';
import 'package:verttice_ui/src/widgets/snap_builder.dart';
import 'package:verttice_ui/src/widgets/themed_progress.dart';
import 'package:video_player/video_player.dart';

class VideoViewerStorage extends StatefulWidget {
  final String path;
  final double? height;
  final double? width;

  const VideoViewerStorage({
    Key? key,
    required this.path,
    this.height,
    this.width,
  }) : super(key: key);
  @override
  State createState() => _VideoViewerStorageState();
}

class _VideoViewerStorageState extends State<VideoViewerStorage> {
  late String _path;
  late Future<String?> _fetchData;

  @override
  void initState() {
    super.initState();
    _path = widget.path;

    _fetchData = VertticeUIConfig.instance.getStorageDownloadURL(path: _path);
  }

  @override
  void didUpdateWidget(covariant VideoViewerStorage oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_path != widget.path) {
      _path = widget.path;
      _fetchData = VertticeUIConfig.instance.getStorageDownloadURL(path: _path);
    }
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<String?>(
        future: _fetchData,
        builder: (BuildContext context, AsyncSnapshot<String?> snapdata) {
          return SnapBuilder<String?>(
              height: widget.height,
              width: widget.width,
              snapshot: snapdata,
              erroBuilder: (dynamic error) => Center(
                    child: CircleAvatar(
                      backgroundColor: Colors.red,
                      child: ThemedIcons.fileUnknow(
                        iconStyle: IconStyle(
                          color: Colors.white,
                          size: 35,
                        ),
                      ),
                    ),
                  ),
              loadingBuilder: () => const ThemedProgress(),
              successBuilder: (String? data) {
                return _body(context, data ?? '');
              });
        });
  }

  Widget _body(BuildContext context, String downloadURL) {
    return LayoutBuilder(
        builder: (BuildContext context, BoxConstraints constraints) {
      final width = widget.width ?? constraints.maxWidth;
      final height = widget.height ??
          ((constraints.maxHeight == double.infinity)
              ? 200
              : constraints.maxHeight);
      return SizedBox(
        width: width,
        height: height,
        child: Material(
          child: SizedBox(
            width: width,
            height: height,
            child: InkWell(
              onTap: () {
                Navigator.push(
                  context,
                  MaterialPageRoute(
                    builder: (context) => VideoViewerFullPage(url: downloadURL),
                  ),
                );
              },
              child: Container(
                decoration: const BoxDecoration(
                  color: Colors.lightBlue,
                  borderRadius: BorderRadius.all(Radius.circular(5.0)),
                ),
                child: Center(
                    child: Column(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    ThemedIcons.video(
                      iconStyle: IconStyle(
                        size: width > mobileWidth ? 60 : 35,
                        color: Colors.white,
                      ),
                    ),
                    if (width > 200)
                      Column(
                        children: const [
                          SizedBox(
                            height: 20,
                          ),
                          SelectableText(
                            "Click here to view the video",
                            style: TextStyle(
                              color: Colors.white,
                            ),
                          )
                        ],
                      ),
                    const Divider(
                      indent: 4,
                      endIndent: 4,
                      color: Colors.white,
                    ),
                    const SelectableText(
                      "Video",
                      style: TextStyle(
                        color: Colors.white,
                      ),
                    )
                  ],
                )),
              ),
            ),
          ),
        ),
      );
    });
  }
}

class VideoViewerFullPage extends StatefulWidget {
  final String url;
  const VideoViewerFullPage({Key? key, required this.url}) : super(key: key);

  @override
  _VideoViewerFullPageState createState() => _VideoViewerFullPageState();
}

class _VideoViewerFullPageState extends State<VideoViewerFullPage> {
  late VideoPlayerController _videoPlayerController;
  late ChewieController _chewieController;
  late String _url;

  @override
  void initState() {
    super.initState();
    _url = widget.url;
    _initVideoPlayer();
  }

  @override
  void dispose() {
    super.dispose();
    _videoPlayerController.dispose();
    _chewieController.dispose();
  }

  @override
  void didUpdateWidget(covariant VideoViewerFullPage oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_url != widget.url) {
      _url = widget.url;
      _initVideoPlayer();
    }
  }

  Future<void> _initVideoPlayer() async {
    _videoPlayerController = VideoPlayerController.network(_url);
    await _videoPlayerController.initialize();
    _chewieController = ChewieController(
      videoPlayerController: _videoPlayerController,
      looping: true,
    );
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        actions: [
          DownloadButton(
            url: widget.url,
            fileType: VFileType.mp4,
          ),
          sizedBoxH16,
        ],
        backgroundColor: Colors.black,
      ),
      body: Container(
        height: MediaQuery.of(context).size.height,
        width: MediaQuery.of(context).size.width,
        color: Colors.grey[850],
        child: LayoutBuilder(
            builder: (BuildContext context, BoxConstraints constraints) {
          final width = constraints.maxWidth;
          final height = constraints.maxHeight == double.infinity
              ? width
              : constraints.maxHeight;

          return SizedBox(
            width: width,
            height: height,
            child: Center(
              child: Stack(
                children: [
                  Container(
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(10.0),
                    ),
                    width: width * 0.9,
                    height: height * 0.9,
                    child: SafeArea(
                      child: Chewie(
                        controller: _chewieController,
                      ),
                    ),
                  ),
                  Positioned(
                      top: 4,
                      right: 4,
                      height: 7,
                      width: 7,
                      child: ThemedIcons.video(
                          iconStyle: IconStyle(color: Colors.lightBlueAccent))),
                ],
              ),
            ),
          );
        }),
      ),
    );
  }
}

==> verttice_ui-0.0.56.tar.gz: lib/src/widgets/files/video_viewer_storage.dart <==
import 'package:chewie/chewie.dart';
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_ui/src/base_config.dart';
import 'package:verttice_ui/src/config/config.dart';
import "package:verttice_ui/src/const/box_sizes.dart";
import "package:verttice_ui/src/const/icons.dart";
import "package:flutter/material.dart";
import 'package:verttice_ui/src/widgets/download_button.dart';
import 'package:verttice_ui/src/widgets/snap_builder.dart';
import 'package:verttice_ui/src/widgets/themed_progress.dart';
import 'package:video_player/video_player.dart';

class VideoViewerStorage extends StatefulWidget {
  final String path;
  final double? height;
  final double? width;

  const VideoViewerStorage({
    Key? key,
    required this.path,
    this.height,
    this.width,
  }) : super(key: key);
  @override
  State createState() => _VideoViewerStorageState();
}

class _VideoViewerStorageState extends State<VideoViewerStorage> {
  late String _path;
  late Future<String?> _fetchData;

  @override
  void initState() {
    super.initState();
    _path = widget.path;

    _fetchData = VertticeUIConfig.instance.getStorageDownloadURL(path: _path);
  }

  @override
  void didUpdateWidget(covariant VideoViewerStorage oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_path != widget.path) {
      _path = widget.path;
      _fetchData = VertticeUIConfig.instance.getStorageDownloadURL(path: _path);
    }
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<String?>(
        future: _fetchData,
        builder: (BuildContext context, AsyncSnapshot<String?> snapdata) {
          return SnapBuilder<String?>(
              height: widget.height,
              width: widget.width,
              snapshot: snapdata,
              erroBuilder: (dynamic error) => Center(
                    child: CircleAvatar(
                      backgroundColor: Colors.red,
                      child: ThemedIcons.fileUnknow(
                        iconStyle: IconStyle(
                          color: Colors.white,
                          size: 35,
                        ),
                      ),
                    ),
                  ),
              loadingBuilder: () => const ThemedProgress(),
              successBuilder: (String? data) {
                return _body(context, data ?? '');
              });
        });
  }

  Widget _body(BuildContext context, String downloadURL) {
    return LayoutBuilder(
        builder: (BuildContext context, BoxConstraints constraints) {
      final width = widget.width ?? constraints.maxWidth;
      final height = widget.height ??
          ((constraints.maxHeight == double.infinity)
              ? 200
              : constraints.maxHeight);
      return SizedBox(
        width: width,
        height: height,
        child: Material(
          child: SizedBox(
            width: width,
            height: height,
            child: InkWell(
              onTap: () {
                Navigator.push(
                  context,
                  MaterialPageRoute(
                    builder: (context) => VideoViewerFullPage(url: downloadURL),
                  ),
                );
              },
              child: Container(
                decoration: const BoxDecoration(
                  color: Colors.lightBlue,
                  borderRadius: BorderRadius.all(Radius.circular(5.0)),
                ),
                child: Center(
                    child: Column(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    ThemedIcons.video(
                      iconStyle: IconStyle(
                        size: width > mobileWidth ? 60 : 35,
                        color: Colors.white,
                      ),
                    ),
                    if (width > 200)
                      Column(
                        children: const [
                          SizedBox(
                            height: 20,
                          ),
                          SelectableText(
                            "Click here to view the video",
                            style: TextStyle(
                              color: Colors.white,
                            ),
                          )
                        ],
                      ),
                    const Divider(
                      indent: 4,
                      endIndent: 4,
                      color: Colors.white,
                    ),
                    const SelectableText(
                      "Video",
                      style: TextStyle(
                        color: Colors.white,
                      ),
                    )
                  ],
                )),
              ),
            ),
          ),
        ),
      );
    });
  }
}

class VideoViewerFullPage extends StatefulWidget {
  final String url;
  const VideoViewerFullPage({Key? key, required this.url}) : super(key: key);

  @override
  _VideoViewerFullPageState createState() => _VideoViewerFullPageState();
}

class _VideoViewerFullPageState extends State<VideoViewerFullPage> {
  late VideoPlayerController _videoPlayerController;
  ChewieController? _chewieController;
  late String _url;

  @override
  void initState() {
    super.initState();
    _url = widget.url;
    _initVideoPlayer();
  }

  @override
  void dispose() {
    super.dispose();
    _videoPlayerController.dispose();
    _chewieController?.dispose();
  }

  @override
  void didUpdateWidget(covariant VideoViewerFullPage oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_url != widget.url) {
      _url = widget.url;
      _initVideoPlayer();
    }
  }

  Future<void> _initVideoPlayer() async {
    _videoPlayerController = VideoPlayerController.network(_url);
    await _videoPlayerController.initialize();
    _chewieController = ChewieController(
      videoPlayerController: _videoPlayerController,
      looping: true,
    );
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        actions: [
          DownloadButton(
            url: widget.url,
            fileType: VFileType.mp4,
          ),
          sizedBoxH16,
        ],
        backgroundColor: Colors.black,
      ),
      body: Container(
        height: MediaQuery.of(context).size.height,
        width: MediaQuery.of(context).size.width,
        color: Colors.grey[850],
        child: LayoutBuilder(
            builder: (BuildContext context, BoxConstraints constraints) {
          final width = constraints.maxWidth;
          final height = constraints.maxHeight == double.infinity
              ? width
              : constraints.maxHeight;

          if (_chewieController == null) {
            return const ThemedProgress();
          }

          return SizedBox(
            width: width,
            height: height,
            child: Center(
              child: Stack(
                children: [
                  Container(
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(10.0),
                    ),
                    width: width * 0.9,
                    height: height * 0.9,
                    child: SafeArea(
                      child: Chewie(
                        controller: _chewieController!,
                      ),
                    ),
                  ),
                  Positioned(
                      top: 4,
                      right: 4,
                      height: 7,
                      width: 7,
                      child: ThemedIcons.video(
                          iconStyle: IconStyle(color: Colors.lightBlueAccent))),
                ],
              ),
            ),
          );
        }),
      ),
    );
  }
}
